use serde::Deserialize;

#[derive(Debug, Clone, Deserialize)]
pub struct Address {
    pub host: String,
    pub port: u16,
}

impl Default for Address {
    fn default() -> Self {
        Self {
            host: "0.0.0.0".into(),
            port: 8000,
        }
    }
}

impl Address {
    pub fn get_url(&self) -> String {
        format!("{}:{}", self.host, self.port)
    }
}

#[derive(Debug, Clone, Deserialize)]
pub struct Pagination {
    pub videos: usize,
    pub comments: usize,
    pub channels: usize,
}

impl Default for Pagination {
    fn default() -> Self {
        Self {
            videos: 10,
            comments: 10,
            channels: 10,
        }
    }
}

#[derive(Debug, Default, Clone, Deserialize)]
pub struct Config {
    pub address: Address,
    pub pagination: Pagination,
}
